EasyExtend.langlets.p4d.conf

Package EasyExtend :: Package langlets :: Package p4d :: Module conf |
[hide private]
[frames] | no frames]

# Module conf

Functions | [hide private]
tokenize(source) |
parse(source, start_symbol=None) |

Variables | [hide private]
| LANGLET_OFFSET = `9728`
| unparse = `Unparser(symbol, token, offset= LANGLET_OFFSET)`
| opt = `eeoptions.getoptions()`
| options = ``{``}``
| compiled_ext = ``'``.pyc``'``
| source_ext = ``'``.p4d``'``
| prompt = ``'``p4d>` `'``
| langlet_name = ``'``p4d``'``